pub struct SkinnedMeshBounds {
pub aabbs: Vec<JointAabb>,
pub aabb_index_to_joint_index: Vec<JointIndex>,
}Expand description
Data that can be used to calculate the AABB of a skinned mesh.
Fields
aabbs: Vec<JointAabb>aabb_index_to_joint_index: Vec<JointIndex>Implementations
Sourceimpl SkinnedMeshBounds
impl SkinnedMeshBounds
Sourcepub fn from_mesh(
mesh: &Mesh,
) -> Result<SkinnedMeshBounds, SkinnedMeshBoundsError>
pub fn from_mesh( mesh: &Mesh, ) -> Result<SkinnedMeshBounds, SkinnedMeshBoundsError>
Create a SkinnedMeshBounds from a Mesh.
The mesh is expected to have position, joint index and joint weight
attributes. If any are missing then a MeshAttributeError is returned.
pub fn iter(&self) -> impl Iterator<Item = (&JointIndex, &JointAabb)>